@@ -92,6 +92,8 @@ QVariant Transfer::data(int role) const {
         return this->packageName();
     case PackageStatusRole:
         return this->packageStatus();
+    case RowNumberRole:
+        return this->rowNumber();
     default:
         return QVariant();
     }
@@ -501,6 +503,9 @@ void Transfer::setStatus(Transfers::Status status) {
                 QDir().rmdir(this->downloadPath());
             }
 
+            if (m_servicePlugin) m_servicePlugin->cancelCurrentOperation();
+            if (m_recaptchaPlugin) m_recaptchaPlugin->cancelCurrentOperation();
+            if (m_decaptchaPlugin) m_decaptchaPlugin->cancelCurrentOperation();
             break;
         case Transfers::Paused:
             if (m_servicePlugin) m_servicePlugin->cancelCurrentOperation();
@@ -842,24 +847,36 @@ void Transfer::start() {
 }
 
 void Transfer::pause() {
-    if (m_connections.isEmpty()) {
-        this->setStatus(Transfers::Paused);
-    }
-    else {
+    switch (this->status()) {
+    case Transfers::Extracting:
+    case Transfers::Converting:
+        return;
+    case Transfers::Downloading:
         foreach (Connection *connection, m_connections) {
             connection->pause();
         }
+
+        return;
+    default:
+        this->setStatus(Transfers::Paused);
+        return;
     }
 }
 
 void Transfer::cancel() {
-    if (m_connections.isEmpty()) {
-        this->setStatus(Transfers::Cancelled);
-    }
-    else {
+    switch (this->status()) {
+    case Transfers::Extracting:
+    case Transfers::Converting:
+        return;
+    case Transfers::Downloading:
         foreach (Connection *connection, m_connections) {
             connection->cancel();
         }
+
+        return;
+    default:
+        this->setStatus(Transfers::Cancelled);
+        return;
     }
 }
 
@@ -1066,9 +1083,8 @@ void Transfer::onCaptchaIncorrect() {
     if ((m_decaptchaPlugin) && (!m_decaptchaPlugin->captchaId().isEmpty())) {
         m_decaptchaPlugin->reportIncorrectCaptchaResponse(m_decaptchaPlugin->captchaId());
     }
-    else {
-        this->onCaptchaRequired();
-    }
+
+    this->onCaptchaRequired();
 }
 
 void Transfer::onCaptchaRejectedByUser() {
