@@ -69,19 +69,35 @@ void UrlChecker::checkFileDownload() {
 
     QUrl redirect = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
 
+    if (redirect.isEmpty()) {
+        redirect = reply->header(QNetworkRequest::LocationHeader).toUrl();
+    }
+
     if (!redirect.isEmpty()) {
         this->testFileDownload(redirect);
     }
     else {
         int statusCode = reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
-        QUrl url = reply->request().url();
 
-        if ((statusCode == 200) || (statusCode == 206)) {
-            QString fileName = QString(reply->rawHeader("Content-Disposition")).section("filename=", -1).remove(QRegExp("\'|\""));
-            this->onUrlChecked(true, url, QString(), fileName, true);
+        switch (statusCode) {
+        case 200:
+        case 201:
+        case 206:
+        {
+            QString fileName = QString(reply->rawHeader("Content-Disposition"));
+            fileName = fileName.mid(fileName.lastIndexOf("filename=") + 1);
+            fileName = fileName.left(fileName.lastIndexOf(';')).remove(QRegExp("\'|\""));
+
+            if (fileName.isEmpty()) {
+                fileName = reply->request().url().toString().section('/', -1);
+            }
+
+            this->onUrlChecked(true, reply->request().url(), QString(), fileName, true);
+            break;
         }
-        else {
+        default:
             this->onUrlChecked(false, QUrl(), QString(), QString(), true);
+            break;
         }
     }
 
